the following patch was just integrated into master:
commit 553fe1cbc72c849504041fb65dbbb1afacd3914b
Author: Jonathan A. Kollasch <jakllsch(a)kollasch.net>
Date: Tue Oct 15 16:45:51 2013 -0500
winent-mb6047: initial WIN Enterprises MB-60470 board port
What works:
- ACPI interrupt routing for onboard devices
- onboard devices including USBs, ATAs, NICs, COM1
What almost works:
- SMI720 VGA BIOS needs forthcoming VGA BIOS hooks in SeaBIOS to work
Untested:
- Interrupt Line Register interrupt routing
- PIRQ interrupt routing
- MPBIOS/MPTABLE interrupt routing
- unpopulated on board revision 1A AC97 audio
- unpopulated PCI-E x16 slot
- unpopulated ExpressCard slot
- HT expansion board
Thanks to WIN Enterprises for providing boards.
Change-Id: I7787f89b3ab454b668c3b75d0d1cde55b8d53c48
Signed-off-by: Jonathan A. Kollasch <jakllsch(a)kollasch.net>
Reviewed-on: http://review.coreboot.org/3975
Reviewed-by: Ronald G. Minnich <rminnich(a)gmail.com>
Tested-by: build bot (Jenkins)
See http://review.coreboot.org/3975 for details.
-gerrit
the following patch was just integrated into master:
commit e1ffd9ef7a04b5a3d167b0767afce08a04721fe8
Author: Jonathan A. Kollasch <jakllsch(a)kollasch.net>
Date: Tue Oct 15 14:26:34 2013 -0500
winent-mb6047: copy tyan/s2891 mainboard directory
Change-Id: I382e30c92a4c428ec53dd959a5fda4927797fb9b
Signed-off-by: Jonathan A. Kollasch <jakllsch(a)kollasch.net>
Reviewed-on: http://review.coreboot.org/3974
Tested-by: build bot (Jenkins)
Reviewed-by: Ronald G. Minnich <rminnich(a)gmail.com>
See http://review.coreboot.org/3974 for details.
-gerrit
Andrew Wu (arw(a)dmp.com.tw) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/3976
-gerrit
commit 6ee575c51ec32dcd1df7dc1783f55148cb310d51
Author: Andrew Wu <arw(a)dmp.com.tw>
Date: Wed Oct 16 13:08:30 2013 +0800
dmp/vortex86ex: Initialize I2C controller base address/IRQ
Change-Id: I22f5c877ed441d59f29801d925ee40b24fb796ce
Signed-off-by: Andrew Wu <arw(a)dmp.com.tw>
---
src/mainboard/dmp/vortex86ex/platform_cfg.h | 31 ++++++++++++++++++++++++++++
src/southbridge/dmp/vortex86ex/southbridge.c | 12 +++++++++++
src/southbridge/dmp/vortex86ex/southbridge.h | 1 +
3 files changed, 44 insertions(+)
diff --git a/src/mainboard/dmp/vortex86ex/platform_cfg.h b/src/mainboard/dmp/vortex86ex/platform_cfg.h
new file mode 100644
index 0000000..61adf57
--- /dev/null
+++ b/src/mainboard/dmp/vortex86ex/platform_cfg.h
@@ -0,0 +1,31 @@
+/*
+ * This file is part of the coreboot project.
+ *
+ * Copyright (C) 2013 DMP Electronics Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+#ifndef _PLATFORM_CFG_H_
+#define _PLATFORM_CFG_H_
+
+/* In-chip PCI device IRQs(0 for disabled). */
+/* Internal I2C */
+#define I2C0_IRQ 10
+
+/* In-chip device I/O base address. */
+/* Internal I2C */
+#define I2C_BASE 0xfb00
+
+#endif
diff --git a/src/southbridge/dmp/vortex86ex/southbridge.c b/src/southbridge/dmp/vortex86ex/southbridge.c
index d8914c0..675cf49 100644
--- a/src/southbridge/dmp/vortex86ex/southbridge.c
+++ b/src/southbridge/dmp/vortex86ex/southbridge.c
@@ -28,6 +28,7 @@
#include "arch/io.h"
#include "chip.h"
#include "southbridge.h"
+#include "mainboard/dmp/vortex86ex/platform_cfg.h"
/* IRQ number to S/B PCI Interrupt routing table reg(0x58/0xb4) mapping table. */
static const unsigned char irq_to_int_routing[16] = {
@@ -418,6 +419,16 @@ static void ex_sb_uart_init(struct device *dev)
//pci_write_config16(SB, SB_REG_UART_CFG_IO_BASE, 0x0);
}
+static void i2c_init(struct device *dev)
+{
+ u8 mapped_irq = irq_to_int_routing[I2C0_IRQ];
+ u32 cfg = 0;
+ cfg |= 1 << 31; // UE = enabled.
+ cfg |= (mapped_irq << 16); // IIRT0.
+ cfg |= I2C_BASE; // UIOA.
+ pci_write_config32(dev, SB_REG_II2CCR, cfg);
+}
+
static int get_rtc_update_in_progress(void)
{
if (cmos_read(RTC_REG_A) & RTC_UIP)
@@ -566,6 +577,7 @@ static void southbridge_init(struct device *dev)
if (dev->device == 0x6011) {
ex_sb_gpio_init(dev);
ex_sb_uart_init(dev);
+ i2c_init(dev);
}
pci_routing_fixup(dev);
diff --git a/src/southbridge/dmp/vortex86ex/southbridge.h b/src/southbridge/dmp/vortex86ex/southbridge.h
index 0cc28fa..316d30a 100644
--- a/src/southbridge/dmp/vortex86ex/southbridge.h
+++ b/src/southbridge/dmp/vortex86ex/southbridge.h
@@ -36,6 +36,7 @@
#define SB_REG_IPFCR 0xc0
#define SB_REG_FRWPR 0xc4
#define SB_REG_STRAP 0xce
+#define SB_REG_II2CCR 0xd4
#define SB1 PCI_DEV(0, 7, 1)
#define SB1_REG_EXT_PIRQ_ROUTE2 0xb4
Paul Menzel (paulepanter(a)users.sourceforge.net) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/3980
-gerrit
commit 99819abf9a3cc7e66ea7b1713a8fff7025e5e862
Author: Paul Menzel <paulepanter(a)users.sourceforge.net>
Date: Sat Oct 19 08:30:09 2013 +0200
util/crossgcc/buildgcc: Check for Wget as it is used to download the archives
Although, Wget is mostly installed by default, there are cases were it
is not.
Downloading tar balls ...
* gmp-5.1.2.tar.bz2 (downloading)./buildgcc: line 272: wget: command not found
So check for it. There only seems to be GNU Wget, so `searchgnu` could
probably be used for this too.
Change-Id: Ia33412d44911f795761bcdb8d44c9b5d215a8fbc
Signed-off-by: Paul Menzel <paulepanter(a)users.sourceforge.net>
---
util/crossgcc/buildgcc | 7 ++++++-
1 file changed, 6 insertions(+), 1 deletion(-)
diff --git a/util/crossgcc/buildgcc b/util/crossgcc/buildgcc
index 3754837..cf19b8c 100755
--- a/util/crossgcc/buildgcc
+++ b/util/crossgcc/buildgcc
@@ -130,6 +130,11 @@ if ! flex --version > /dev/null 2> /dev/null; then
exit 1
fi
+WGET=wget
+if ! $WGET --version > /dev/null 2> /dev/null; then
+ printf "${RED}ERROR:${red} Missing tool chain (program for downloading archives): wget${NC}\n" >&2
+fi
+
cleanup()
{
printf "Cleaning up temporary files... "
@@ -269,7 +274,7 @@ for ARCHIVE in $GMP_ARCHIVE $MPFR_ARCHIVE $MPC_ARCHIVE $LIBELF_ARCHIVE \
test -f tarballs/$FILE && printf "(cached)" || (
printf "(downloading)"
cd tarballs
- wget --no-check-certificate -q $ARCHIVE
+ $WGET --no-check-certificate -q $ARCHIVE
)
test -f tarballs/$FILE || \
printf "\n${RED}Failed to download $FILE.${NC}\n"
Andrew Wu (arw(a)dmp.com.tw) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/3958
-gerrit
commit 360222b4f5419529b4e95eac0c0d641446628329
Author: Andrew Wu <arw(a)dmp.com.tw>
Date: Sat Oct 19 01:33:08 2013 +0800
vortex86ex: Defer checking PS/2 keyboard controller system flag
Don't check keyboard controller system flag until before calling
pc_keyboard_init(). This makes waiting time shorter.
Change-Id: I2cdb533a5b25575e1717434533a60decf748f6d8
Signed-off-by: Andrew Wu <arw(a)dmp.com.tw>
---
src/southbridge/dmp/vortex86ex/southbridge.c | 9 ++++++++-
1 file changed, 8 insertions(+), 1 deletion(-)
diff --git a/src/southbridge/dmp/vortex86ex/southbridge.c b/src/southbridge/dmp/vortex86ex/southbridge.c
index d8914c0..ddb99b8 100644
--- a/src/southbridge/dmp/vortex86ex/southbridge.c
+++ b/src/southbridge/dmp/vortex86ex/southbridge.c
@@ -138,7 +138,13 @@ static void upload_dmp_keyboard_firmware(struct device *dev)
// disable firmware uploading.
pci_write_config32(dev, SB_REG_IPFCR, reg_sb_c0 & ~0x400L);
- // wait keyboard controller ready by checking status port bit 2.
+}
+
+static void kbc_wait_system_flag(void)
+{
+ /* wait keyboard controller ready by checking system flag
+ * (status port bit 2).
+ */
post_code(POST_KBD_CHK_READY);
while ((inb(0x64) & 0x4) == 0) {
}
@@ -571,6 +577,7 @@ static void southbridge_init(struct device *dev)
fix_cmos_rtc_time();
rtc_init(0);
+ kbc_wait_system_flag();
pc_keyboard_init(0);
}
the following patch was just integrated into master:
commit 6a4e9b547a0e73fb48ee228357820fb3ba85cec2
Author: Paul Menzel <paulepanter(a)users.sourceforge.net>
Date: Fri Oct 18 09:42:55 2013 +0200
get_bus_conf.c: reindent with indent
Change-Id: Ia0c37339aa69b92a1b518fa5e49adc4a7628ae5d
Signed-off-by: Paul Menzel <paulepanter(a)users.sourceforge.net>
Reviewed-on: http://review.coreboot.org/3979
Reviewed-by: Ronald G. Minnich <rminnich(a)gmail.com>
Tested-by: build bot (Jenkins)
See http://review.coreboot.org/3979 for details.
-gerrit